"""Submodel for `message.py`."""
from datetime import date
from typing import Optional

from pydantic import BaseModel

from .image import Image


class LinkedTopic(BaseModel):
    """Represents linked topic of message entity."""
    id: int
    topic_url: str
    thread_id: int
    topic_id: int
    type: str
    name: Optional[str] = None
    russian: Optional[str] = None
    image: Optional[Image] = None
    url: Optional[str] = None
    kind: Optional[str] = None
    score: Optional[float] = None
    status: Optional[str] = None
    episodes: Optional[int] = None
    episodes_aired: Optional[int] = None
    aired_on: Optional[date] = None
    released_on: Optional[date] = None



"""Submodel for `anime.py`."""
from typing import Literal

from pydantic import BaseModel


class Genre(BaseModel):
    """Represents genre of anime entity."""
    id: int
    name: str
    russian: str
    kind: Literal['genre', 'demographic', 'theme']
    entry_type: Literal['Anime', 'Manga']
